@@ -252,7 +252,7 @@ class Blaster():
                 trim = len(nucl_sequence) % 3
                 if trim != 0:
                     nucl_sequence = nucl_sequence + Seq('N' * (3 - trim))
-                prot_sequence = nucl_sequence.replace('-', 'N').translate(
+                prot_sequence = nucl_sequence.replace('-', '').translate(
                     table=11, to_stop=True, gap='-')
 
                 id = str(hit_data['SEQUENCE'] +
